@@ -34,6 +34,10 @@
 #include <ctype.h>
 #include "version.h"
 
+#define PTOMM(p) (0.3528 * (p)) /* pt to mm */
+#define HEIGHT PTOMM(592) /* \textheight default in pt */
+#define SKIPR 1.2 /* default \baselineskip ratio (to multiply with font) */
+
 typedef struct {
 	char* tab;	/* actual escapes */
 	int size;	/* escape tab len */
@@ -55,6 +59,9 @@ typedef struct {
 	unsigned int repeat;	/* repeat table headers for each LaTeX table section or not */
 	unsigned int vlines;	/* insert vertical lines between columns or not */
 	unsigned int hlines;	/* insert horizontal lines between rows or not */
+	unsigned int paper;	/* output paper type */
+	unsigned int font;	/* expected font size */
+	unsigned int land;	/* landscape mode */
 	char* clrrow;	/* row graylevel (from 0 to 1) */
 	texcape* tex;	/* TeX escapes */
 } config;
@@ -70,10 +77,12 @@ void rtfm(char* prog) {
    printf("	[--guess] (CSV) guess separator and block |\n"
 		"	[--separator <(c)omma|(s)emicolon|(t)ab|s(p)ace|co(l)on>] (CSV's comma)\n"
 		"	[--block <(q)uote|(d)ouble|(n)one>] (CSV) block delimiter (e.g: none)\n");
-   printf("	[--lines n] (LaTeX) rows per table: useful for long tabulars\n");
+   printf("	[--lines n] (LaTeX) rows per table: useful for long tabulars |\n");
+   printf("		[--font n] font size used (in pt)\n");
    printf("	[--position <l|c|r>] (LaTeX) text align in cells\n");
    printf("	[--colorrows graylevel] (LaTeX) alternate gray rows (e.g: 0.75)\n");
    printf("	[--reduce level] (LaTeX) reduce table size (e.g: 1)\n");
+   printf("	[--landscape] (LaTeX) use landscape mode\n");
    printf("	[--repeatheader] (LaTeX) repeat table header (for long tables)\n");
    printf("	[--nohlines] (LaTeX) don't put hline between table rows\n");
    printf("	[--novlines] (LaTeX) don't put vline between columns\n");
@@ -108,13 +117,15 @@ config* parseOptions (config* conf, int argc, char **argv) {
 		{"repeatheader", 0, NULL, 'e'},
 		{"novlines",     0, NULL, 'y'},
 		{"nohlines",     0, NULL, 'z'},
+		{"landscape",    0, NULL, 'a'},
+		{"font",         1, NULL, 'f'},
 		{NULL, 0, NULL,  0} /* marks end-of-list */
 	};
 #endif
 #if defined USE_GETOPT
-	while ((opt = getopt (argc, argv, "hvgnxteyz?b:l:p:s:c:r:")) != EOF) {
+	while ((opt = getopt (argc, argv, "hvgnxteyza?b:l:p:s:c:r:f:")) != EOF) {
 #else
-	while ((opt = getopt_long (argc, argv, "hvgnxteyz?b:l:p:s:c:r:", long_options, &longopt_index)) > 0) {
+	while ((opt = getopt_long (argc, argv, "hvgnxteyza?b:l:p:s:c:r:f:", long_options, &longopt_index)) > 0) {
 #endif
 		switch (opt) {
 			case '?':
@@ -200,17 +211,30 @@ config* parseOptions (config* conf, int argc, char **argv) {
 			case 'z': /*don't draw hlines between rows*/
 					conf->hlines = 0;
 					break;
+			case 'a': /*landscape*/
+					conf->land = 1;
+					break;
+			case 'f': /*output font size*/
+					if (isdigit(optarg[0])) {
+						conf->font = atoi(optarg);
+					} else {
+						fprintf(stderr,
+						"option \"font\" need a positive integer value\n");
+						exit(EXIT_FAILURE);
+					}
+					break;
 		}
 	}
 	return conf;
 }
+
 int guessCSV(config* conf, FILE* in) {
 /* guess the block delimiter and the csv separator */
 	int token;
 
 	token = getc(in); /* first char is block delimiter */
 	if (token == EOF) {
-		fprintf(stderr, "ERROR: emtpy file ?\n");
+		fprintf(stderr, "ERROR: empty file ?\n");
 		return -1;
 	} else if (ispunct(token) || token == ' ') {
 	       	/* found first block delimiter, act this way */
@@ -313,6 +337,14 @@ void getMaximums(config* conf, FILE* in)  {
 	return;
 }
 
+unsigned int guessLinesPerPage(unsigned int font, double height) {
+/**
+ * return: estimated number of lines per page, given page height in milimeter and font size in point
+ */
+	return  height / (PTOMM(SKIPR * font));
+}
+
+
 void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 /* substitutes CSV sep by LaTeX newsep and some TeX code */
 	int token = 0;
@@ -330,6 +362,13 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 
 	max = numcols = conf->cols;
 	csvrows = conf->rows;
+
+	/* optimize a bit lines per tabular */
+	if (!conf->longtable && !conf->lines) {
+		conf->lines = guessLinesPerPage(conf->font ? conf->font : 10, conf->land ? (HEIGHT / 1.414) : HEIGHT);
+		fprintf(stderr, "guessed %d lines per page\n", conf->lines);
+	}
+
 	/* choose infinity when conf->lines is 0 */
 	lines = (conf->lines) ? conf->lines : MAXUINT;
 
@@ -496,7 +535,21 @@ void doTeXdoc(config* conf, FILE* in, FILE* out) {
 
 	numcols = maxcols = conf->cols;
 	if (conf->header) {
-		fprintf(out, "\\documentclass[a4paper]{article}\n");
+		if (conf->land) {
+			if (conf->font)
+				fprintf(out, "\\documentclass[%dpt,a4paper,landscape]{article}\n", conf->font);
+			else {
+				fprintf(out, "\\documentclass[a4paper,landscape]{article}\n");
+				conf->font = 10; /* pt */
+			}
+		} else {
+			if (conf->font)
+				fprintf(out, "\\documentclass[%dpt,a4paper]{article}\n", conf->font);
+			else {
+				fprintf(out, "\\documentclass[a4paper]{article}\n");
+				conf->font = 10; /* pt */
+			}
+		}
 		fprintf(out, "\\usepackage[T1]{fontenc}\n");
 		fprintf(out, "\\usepackage[utf8]{inputenc}\n");
 		if (conf->red) {
@@ -579,6 +632,8 @@ int main (int argc, char **argv) {
 	conf->repeat = 0;      /* default; do not repeat the header row */
 	conf->vlines = 1;      /* default; draw lines between columns */
 	conf->hlines = 1;      /* default; draw lines between rows */
+	conf->font = 0;        /* default to LaTeX defaults */
+	conf->land = 0;        /* default to LaTeX defaults */
 
 	/* TeX charaters to escape */
 	conf->tex = (texcape*)malloc(sizeof(texcape));
